@@ -31,7 +31,7 @@ import codecs
 if sys.version_info[0] == 2:
     sys.stdout = codecs.getwriter('utf-8')(sys.stdout)
 
-__VERSION__ = '0.5.1'
+__VERSION__ = '0.5.3'
 
 DESCRIPTION = 'bumpversion: v{} (using Python v{})'.format(
     __VERSION__,
@@ -70,7 +70,7 @@ class BaseVCS(object):
         f.write(message.encode('utf-8'))
         f.close()
         subprocess.check_output(cls._COMMIT_COMMAND + [f.name], env=dict(
-            list(os.environ.items()) + [('HGENCODING', 'utf-8')]
+            list(os.environ.items()) + [(b'HGENCODING', b'utf-8')]
         ))
         os.unlink(f.name)
 
@@ -270,8 +270,8 @@ class ConfiguredFile(object):
             ))
 
         if not dry_run:
-            with io.open(self.path, 'wt', encoding='utf-8') as f:
-                f.write(file_content_after)
+            with io.open(self.path, 'wb') as f:
+                f.write(file_content_after.encode('utf-8'))
 
     def __str__(self):
         return self.path
@@ -662,6 +662,10 @@ def main(original_args=None):
         defaults['current_version'] = vcs_info['current_version']
 
     config = RawConfigParser('')
+
+    # don't transform keys to lowercase (which would be the default)
+    config.optionxform = lambda option: option
+
     config.add_section('bumpversion')
 
     explicit_config = hasattr(known_args, 'config_file')
@@ -763,7 +767,7 @@ def main(original_args=None):
         else:
             logger.info(message)
 
-    parser2 = argparse.ArgumentParser(add_help=False, parents=[parser1])
+    parser2 = argparse.ArgumentParser(prog='bumpversion', add_help=False, parents=[parser1])
     parser2.set_defaults(**defaults)
 
     parser2.add_argument('--current-version', metavar='VERSION',
@@ -820,6 +824,7 @@ def main(original_args=None):
             logger.info("Opportunistic finding of new_version failed")
 
     parser3 = argparse.ArgumentParser(
+        prog='bumpversion',
         description=DESCRIPTION,
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         conflict_handler='resolve',
@@ -875,8 +880,8 @@ def main(original_args=None):
 
     if args.dry_run:
         logger.info("Dry run active, won't touch any files.")
-
-    if not new_version:
+    
+    if args.new_version:
         new_version = vc.parse(args.new_version)
 
     logger.info("New version will be '{}'".format(args.new_version))
